helanal
==============================
[//]: # (Badges)

| **Latest release** | [![Last release tag][badge_release]][url_latest_release] ![GitHub commits since latest release (by date) for a branch][badge_commits_since]  [![Documentation Status][badge_docs]][url_docs]|
| :----------------- | :------- |
| **Status**         | [![GH Actions Status][badge_actions]][url_actions] [![codecov][badge_codecov]][url_codecov] |
| **Community**      | [![License: GPL v2][badge_license]][url_license]  [![Powered by MDAnalysis][badge_mda]][url_mda]|

[badge_actions]: https://github.com/MDAnalysis/helanal/actions/workflows/gh-ci.yaml/badge.svg
[badge_codecov]: https://codecov.io/gh/MDAnalysis/helanal/branch/main/graph/badge.svg
[badge_commits_since]: https://img.shields.io/github/commits-since/MDAnalysis/helanal/latest
[badge_docs]: https://readthedocs.org/projects/helanal/badge/?version=latest
[badge_license]: https://img.shields.io/badge/License-GPLv2-blue.svg
[badge_mda]: https://img.shields.io/badge/powered%20by-MDAnalysis-orange.svg?logoWidth=16&logo=data:image/x-icon;base64, 
[badge_release]: https://img.shields.io/github/release-pre/MDAnalysis/helanal.svg
[url_actions]: https://github.com/MDAnalysis/helanal/actions?query=branch%3Amain+workflow%3Agh-ci
[url_codecov]: https://codecov.io/gh/MDAnalysis/helanal/branch/main
[url_docs]: https://helanal.readthedocs.io/en/latest/?badge=latest
[url_latest_release]: https://github.com/MDAnalysis/helanal/releases
[url_license]: https://www.gnu.org/licenses/gpl-2.0
[url_mda]: https://www.mdanalysis.org

A package to characterise the geometry of protein helicies.

helanal is bound by a [Code of Conduct](https://github.com/MDAnalysis/helanal/blob/main/CODE_OF_CONDUCT.md).

### Installation

To build helanal from source,
we highly recommend using virtual environments.
If possible, we strongly recommend that you use
[Anaconda](https://docs.conda.io/en/latest/) as your package manager.
Below we provide instructions both for `conda` and
for `pip`.

#### With conda

Ensure that you have [conda](https://docs.conda.io/projects/conda/en/latest/user-guide/install/index.html) installed.

Create a virtual environment and activate it:

```
conda create --name helanal
conda activate helanal
```

Install the development and documentation dependencies:

```
conda env update --name helanal --file devtools/conda-envs/test_env.yaml
conda env update --name helanal --file docs/requirements.yaml
```

Build this package from source:

```
pip install -e .
```

If you want to update your dependencies (which can be risky!), run:

```
conda update --all
```

And when you are finished, you can exit the virtual environment with:

```
conda deactivate
```

#### With pip

To build the package from source, run:

```
pip install .
```

If you want to create a development environment, install
the dependencies required for tests and docs with:

```
pip install ".[test,doc]"
```

### Copyright

The helanal source code is hosted at https://github.com/MDAnalysis/helanal
and is available under the GNU General Public License, version 2 (see the file [LICENSE](https://github.com/MDAnalysis/helanal/blob/main/LICENSE)).

Copyright (c) 2024, Your name (or your organization/company/team)


#### Acknowledgements
 
Project based on the 
[MDAnalysis Cookiecutter](https://github.com/MDAnalysis/cookiecutter-mda) version 0.1.
Please cite [MDAnalysis](https://github.com/MDAnalysis/mdanalysis#citation) when using helanal in published work.
